==> tine20-allinone_2020.03.4.tar.bz2: Crm/js/Crm-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "All leads"
: "Të gjithë drejtimet"

, "Default Lead List"
: "Lista e Paracaktuar e Drejtimeve"

, "The default list for new leads"
: "Lista e paracaktuar për drejtime të reja"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Niveli i veprimeve për të cilët doni të njoftoheni"

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Send Notifications e-mails to responsible"
: ""

, "Get notifications e-mails for action to responsible"
: ""

, "Send Notifications e-mails to customer"
: ""

, "Get notifications e-mails for action to customer"
: ""

, "Send Notifications e-mails to partner"
: ""

, "Get notifications e-mails for action to partner"
: ""

, "Default Favorite"
: "Të Preferuarat e Paracaktuara"

, "The default favorite which is loaded on crm startup"
: "Preferenca e paracaktar që ngarkohet ne fillimin e crm"

, "New Lead"
: "Drejtim i ri"

, "Tags"
: "Etiketime"

, "Lead name"
: "Emri Drejtues"

, "Responsible"
: "Përgjegjës"

, "Partner"
: "Partner"

, "Customer"
: "Klient"

, "Leadstate"
: "Statusi Drejtues"

, "Leadtype"
: "Tipi Drejtues"

, "Leadsource"
: "Burimi Drejtues"

, "Probability"
: "Probabiliteti"

, "Turnover"
: "Xhiro"

, "Estimated end"
: "Fundi i pritshëm "

, "Probable Turnover"
: "Xhiro e mundshme"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Contact"
: "Kontakt"

, "CRM Role"
: "Roli CRM"

, "Tasks"
: "Detyrë"

, "No Tasks to display"
: "Nuk ka Detyra për tu shfaqur"

, "Summary"
: "Përmbledhje"

, "Add a task..."
: "Shto detyrë..."

, "Due Date"
: "Data e caktuar"

, "Priority"
: "Prioriteti"

, "Percent"
: "Përqind"

, "Status"
: "Status"

, "Organizer"
: ""

, "Add new {0}"
: "Shto të ri {0}"

, "Unlink {0}"
: "Ç'lidh"

, "Unlink selected {0}"
: "Ç'lidh {0} të zgjedhur "

, "Edit {0}"
: "Modifiko {0}"

, "Edit selected {0}"
: "Modifiko {0} të zgjedhur"

, "Please choose the Lead to add the contacts to"
: "Ju lutem zgjidhni Drejtimin ku të shtohen kontaktet"

, "Please select the attenders' role"
: "Ju lutem zgjidhni rolin e vijuesve"

, "Lead, Leads"
: [
  "Drejtim"
 ,"Drejtime"

]
, "Select Lead"
: "Zgjidh Drejtimin"

, "Role"
: "Roli"

, "Select Role"
: "Zgjidh Rolin"

, "Adding {0} contacts to lead"
: "Duke i shtuar drejtimit {0} kontakte"

, "Phone"
: "Telefon"

, "Mobile"
: "Celular"

, "Fax"
: "Faks"

, "E-Mail"
: "E-Postë"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Start"
: "Fillo"

, "Change type to Customer"
: "Ndrysho tipin Klientit"

, "Change type to Responsible"
: "Ndysho tipin Përgjegjësit"

, "Change type to Partner"
: "Ndrysho tipin Partnerit"

, "Change contact type"
: "Ndrysho tipin e kontaktit"

, "Search for Contacts to add ..."
: "Kërko Kontakte për tu shtuar"

, "Name"
: "Emri"

, "Address"
: "Adresë"

, "Data"
: "Data"

, "Cellphone"
: "Celular"

, "End"
: "Fund"

, "You do not have the run right for the Tasks application or it is not activated."
: "Ju nuk keni të drejtën e ekzekutimit të aplikacionit të Detyrave ose nuk është i aktivizuar. "

, "Products"
: "Produkte"

, "You do not have the run right for the Sales application or it is not activated."
: "Ju nuk keni të drejtën e ekzekutimit të aplikacionit të Shitjeve ose nuk është i aktivizuar."

, "Enter lead name"
: ""

, "Expected turnover"
: "Xhiroja e pritshme"

, "Description"
: "Përshkrim"

, "Enter description"
: "Vendosni përshkrimin"

, "lead list, lead lists"
: [
  "listë drejtimi"
 ,"lista drejtimi"

]
, "lead lists"
: "lista drejtimi"

, "Quick Search"
: "Kërkim i Shpejtë"

, "Last Modified Time"
: "Koha e ndryshimit të fundit"

, "Last Modified By"
: "Ndryshimi i fundit nga"

, "Creation Time"
: "Koha e krijimit"

, "Created By"
: "Krijuar nga"

, "X Lead"
: ""

, "Archived"
: ""

, "Product"
: "Produkt"

, "Price"
: "Çmim"

, "Quantity"
: "Sasi"

, "Search for Products to add ..."
: "Kërko për produkte për të shtuar... "

, "All leads I have read grants for"
: "Të gjithë drejtimet qe kam të drejtë leximi"

, "Last modified by me"
: "E fundit e ndryshuar nga Unë"

, "All leads that I have last modified"
: "Të gjithë drejtimet qe unë kam ndryshuar së fundmi"

, "My leads"
: "Drejtimet e mia"

, "All leads that I am responsible for"
: "Të gjithe Drejtimet që unë jam përgjegjës"

, "Leads with overdue tasks"
: "Drejtime me detyra të vonuara"

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "hapur"

, "contacted"
: "i kontaktuar"

, "waiting for feedback"
: "Duke pritur për përgjigje"

, "quote sent"
: "citimi u dërgua"

, "accepted"
: "i pranuar"

, "lost"
: "humbur"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "RiShitës"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "State"
: "Gjendja"

, "Source"
: "Burimi"

, "Scheduled end"
: "Fundi i planifikuar"

, "Folder"
: "Dosje"

, "Updated by"
: "Përditësuar nga"

, "Updated Fields:"
: "Përditësimet dështuan"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Drejtimi %s u ndryshua"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Drejtimi %s u krijua"

, "Task"
: "Detyrë"

, "Lead Data"
: "Të dhëna Drejtuese"

, "End Scheduled"
: "Përfundo planifikimet"

, "Contacts"
: "Kontakte"

, "Telephone"
: "Telefon"

, "Email"
: "E-Postë"

, "low"
: "ulët"

, "normal"
: "normal"

, "high"
: "lartë"

, "urgent"
: "urgjent"

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "manage shared lead folders"
: "menaxho dosjet e ndara drejtuese "

, "Create new shared lead folders"
: "Krijo dosje drejtuese të ndara të reja"

, "manage shared leads favorites"
: "menaxho preferencialet drejtuese të ndara"

, "Create or update shared leads favorites"
: "Krijo ose përditëso preferencialet drejtuese të ndara"




, "Lead"
: "Drejtim"

, "lead list"
: "listë drejtimi"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Crm/js/Crm-lang-sq-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Crm **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Crm'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:49+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Albanian (http://www.transifex.com/tine20/tine20/language/sq/)\nLanguage: sq\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Customer"
: "Klient"

, "Partner"
: "Partner"

, "Phone"
: "Telefon"

, "Mobile"
: "Celular"

, "Fax"
: "Faks"

, "E-Mail"
: "E-Postë"

, "Web"
: "Web"

, "Street"
: ""

, "Postalcode"
: ""

, "City"
: ""

, "Status"
: "Status"

, "Start"
: "Fillo"

, "Estimated end"
: "Fundi i pritshëm "

, "Leadtype"
: "Tipi Drejtues"

, "Leadsource"
: "Burimi Drejtues"

, "Tags"
: "Etiketime"

, "Lead name"
: "Emri Drejtues"

, "Responsible"
: "Përgjegjës"

, "Leadstate"
: "Statusi Drejtues"

, "Probability"
: "Probabiliteti"

, "Turnover"
: "Xhiro"

, "End"
: "Fund"

, "Probable Turnover"
: "Xhiro e mundshme"

, "Resubmission Date"
: ""

, "Import leads"
: ""

, "Add new {0}"
: "Shto të ri {0}"

, "Unlink {0}"
: "Ç'lidh"

, "Unlink selected {0}"
: "Ç'lidh {0} të zgjedhur "

, "Edit {0}"
: "Modifiko {0}"

, "Edit selected {0}"
: "Modifiko {0} të zgjedhur"

, "New Lead"
: "Drejtim i ri"

, "Products"
: "Produkte"

, "Product"
: "Produkt"

, "Description"
: "Përshkrim"

, "Price"
: "Çmim"

, "Quantity"
: "Sasi"

, "Search for Products to add ..."
: "Kërko për produkte për të shtuar... "

, "1"
: ""

, "Notifications are disabled"
: ""

, "Send Notification?"
: ""

, "Changes to this lead might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "Tasks"
: "Detyrë"

, "You do not have the run right for the Tasks application or it is not activated."
: "Ju nuk keni të drejtën e ekzekutimit të aplikacionit të Detyrave ose nuk është i aktivizuar. "

, "You do not have the run right for the Sales application or it is not activated."
: "Ju nuk keni të drejtën e ekzekutimit të aplikacionit të Shitjeve ose nuk është i aktivizuar."

, "Lead, Leads"
: [
  "Drejtim"
 ,"Drejtime"

]
, "Enter lead name"
: ""

, "Expected turnover"
: "Xhiroja e pritshme"

, "Enter description"
: "Vendosni përshkrimin"

, "lead list, lead lists"
: [
  "listë drejtimi"
 ,"lista drejtimi"

]
, "lead lists"
: "lista drejtimi"

, "Quick Search"
: "Kërkim i Shpejtë"

, "Last Modified Time"
: "Koha e ndryshimit të fundit"

, "Last Modified By"
: "Ndryshimi i fundit nga"

, "Creation Time"
: "Koha e krijimit"

, "Created By"
: "Krijuar nga"

, "X Lead"
: ""

, "read-only"
: ""

, "Archived"
: ""

, "Contact"
: "Kontakt"

, "CRM Role"
: "Roli CRM"

, "Change type to Customer"
: "Ndrysho tipin Klientit"

, "Change type to Responsible"
: "Ndysho tipin Përgjegjësit"

, "Change type to Partner"
: "Ndrysho tipin Partnerit"

, "Change contact type"
: "Ndrysho tipin e kontaktit"

, "Search for Contacts to add ..."
: "Kërko Kontakte për tu shtuar"

, "Name"
: "Emri"

, "Address"
: "Adresë"

, "Data"
: "Data"

, "Cellphone"
: "Celular"

, "Role"
: "Roli"

, "Please choose the Lead to add the contacts to"
: "Ju lutem zgjidhni Drejtimin ku të shtohen kontaktet"

, "Please select the attenders' role"
: "Ju lutem zgjidhni rolin e vijuesve"

, "Select Lead"
: "Zgjidh Drejtimin"

, "Select Role"
: "Zgjidh Rolin"

, "Adding {0} contacts to lead"
: "Duke i shtuar drejtimit {0} kontakte"

, "No Tasks to display"
: "Nuk ka Detyra për tu shfaqur"

, "Summary"
: "Përmbledhje"

, "Add a task..."
: "Shto detyrë..."

, "Due Date"
: "Data e caktuar"

, "Priority"
: "Prioriteti"

, "Percent"
: "Përqind"

, "Organizer"
: ""

, "All leads"
: "Të gjithë drejtimet"

, "Default Lead List"
: "Lista e Paracaktuar e Drejtimeve"

, "The default list for new leads"
: "Lista e paracaktuar për drejtime të reja"

, "Get Notification E-mails"
: ""

, "The level of actions you want to be notified about."
: "Niveli i veprimeve për të cilët doni të njoftoheni"

, "Send Notifications e-mails for own actions"
: ""

, "Get notifications e-mails for actions you did yourself"
: ""

, "Default Favorite"
: "Të Preferuarat e Paracaktuara"

, "The default favorite which is loaded on crm startup"
: "Preferenca e paracaktar që ngarkohet ne fillimin e crm"

, "controls sending notification of Leads"
: ""

, "send notification)description"
: ""

, "send notification to all access container"
: ""

, "send notification to responsible"
: ""

, "send notification to responsible)description"
: ""

, "send notification to customer"
: ""

, "send notification to partner"
: ""

, "Lead States Available"
: ""

, "Possible lead status, with their associated turnover probabilities. If a status is flagged, leads with this status are treated as closed."
: ""

, "open"
: "hapur"

, "contacted"
: "i kontaktuar"

, "waiting for feedback"
: "Duke pritur për përgjigje"

, "quote sent"
: "citimi u dërgua"

, "accepted"
: "i pranuar"

, "lost"
: "humbur"

, "Lead Sources Available"
: ""

, "Possible lead sources. If a source is flagged as archived, leads of this source are treated as closed."
: ""

, "Lead Types Available"
: ""

, "Possible lead types."
: ""

, "Reseller"
: "RiShitës"

, "Enabled Features"
: ""

, "Enabled Features in CRM Application."
: ""

, "Lead Import"
: ""

, "Lead Notification Confirmation"
: ""

, "Add new task on lead import"
: ""

, "Automatically creates a task for the responsible person if a new lead is imported."
: ""

, "Send notification e-mail on lead import"
: ""

, "Sends an e-mail to all responsible persons for the imported leads."
: ""

, "Lead duplicate check fields"
: ""

, "These fields are checked when a new lead is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: ""

, "Lead Data"
: "Të dhëna Drejtuese"

, "End Scheduled"
: "Përfundo planifikimet"

, "Contacts"
: "Kontakte"

, "Telephone"
: "Telefon"

, "Email"
: "E-Postë"

, "low"
: "ulët"

, "normal"
: "normal"

, "high"
: "lartë"

, "urgent"
: "urgjent"

, "CSV all data"
: ""

, "Lead CSV import"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Leads imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Edit new lead"
: ""

, "The following leads have just been imported into lead list %s"
: ""

, "%s new leads have been imported"
: ""

, "GENDER_Lead"
: ""

, "Show Closed"
: ""

, "Task"
: "Detyrë"

, "State"
: "Gjendja"

, "Source"
: "Burimi"

, "Scheduled end"
: "Fundi i planifikuar"

, "Folder"
: "Dosje"

, "Updated by"
: "Përditësuar nga"

, "Updated Fields:"
: "Përditësimet dështuan"

, "'%s' changed from '%s' to '%s'."
: ""

, "Lead %s has been changed"
: "Drejtimi %s u ndryshua"

, "Lead %s has been deleted"
: ""

, "Lead %s has been created"
: "Drejtimi %s u krijua"

, "This Lead state is set to read-only therefore updating this Lead is not possible."
: ""

, "All leads I have read grants for"
: "Të gjithë drejtimet qe kam të drejtë leximi"

, "Last modified by me"
: "E fundit e ndryshuar nga Unë"

, "All leads that I have last modified"
: "Të gjithë drejtimet qe unë kam ndryshuar së fundmi"

, "My leads"
: "Drejtimet e mia"

, "All leads that I am responsible for"
: "Të gjithe Drejtimet që unë jam përgjegjës"

, "Leads with overdue tasks"
: "Drejtime me detyra të vonuara"

, "manage shared lead folders"
: "menaxho dosjet e ndara drejtuese "

, "Create new shared lead folders"
: "Krijo dosje drejtuese të ndara të reja"

, "manage shared leads favorites"
: "menaxho preferencialet drejtuese të ndara"

, "Create or update shared leads favorites"
: "Krijo ose përditëso preferencialet drejtuese të ndara"




, "Lead"
: "Drejtim"

, "lead list"
: "listë drejtimi"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
